@@ -1,6 +1,10 @@
+#include <R.h>
 /* RSB #include <u.h>
 #include <libc.h>*/
 #include "map.h"
+// CRAN change 2012-12-10
+#define abort() error("fatal error in mapproj")
+
 
 int Xstereographic(struct place *place, double *x, double *y);
 
